@@ -5,8 +5,8 @@ visregResid <- function(fit) {
       P <- predict(fit, type="prob")
       rr <- (fit$y==colnames(P)[2]) - P[,2]
     }
-  } else if ("svm" %in% class(fit)) {
-    rr <- fit$y - fit$fitted
+#   } else if ("svm" %in% class(fit)) {
+#     rr <- fit$y - fit$fitted
   } else if ('coxph' %in% class(fit)) {
     rr <- residuals(fit, type='deviance')
   } else if ('betareg' %in% class(fit)) {
@@ -14,6 +14,6 @@ visregResid <- function(fit) {
   } else {
     rr <- residuals(fit)
   }
-  if (class(fit)[1]!="mlm" && length(rr)>0) rr <- rr[!is.na(rr)]
+  if (!is.matrix(rr) & length(rr)>0) rr <- rr[!is.na(rr)]
   rr
 }
